@@ -9,23 +9,25 @@ def setSkiff(s):
 
 class SkiffAction(object):
     """SkiffAction"""
-    def __init__(self, options=None, **kwargs):
+    def __init__(self, options):
         super(SkiffAction, self).__init__()
-        if not options:
-            options = kwargs
 
+        self._json = options
         self.__dict__.update(options)
+        self.refresh = self.reload
 
     def __repr__(self):
         return '<%s (#%s) %s>' % (self.type, self.id, self.status)
 
+    def reload(self):
+        return get(self.id)
+
 
 def all(params=None, **kwargs):
     if not params:
         params = kwargs
 
-    r = skiff.get('/actions', params)
-    return [SkiffAction(a) for a in r['actions']]
+    return skiff.get('/actions', (lambda r: [SkiffAction(a) for a in r['actions']]), params)
 
 
 def get(aid):
