@@ -13,18 +13,22 @@ class SkiffRegion(object):
         if not options:
             options = kwargs
 
+        self._json = options
         self.__dict__.update(options)
+        self.refresh = self.reload
 
     def __repr__(self):
         return '<%s (%s)>' % (self.name, self.slug)
 
+    def reload(self):
+        return get(self.slug)
+
 
 def all(params=None, **kwargs):
     if not params:
         params = kwargs
 
-    r = skiff.get('/regions', params)
-    return [SkiffRegion(a) for a in r['regions']]
+    return skiff.get('/regions', (lambda r: [SkiffRegion(a) for a in r['regions']]), params)
 
 
 def get(r):
