@@ -13,18 +13,22 @@ class SkiffSize(object):
         if not options:
             options = kwargs
 
+        self._json = options
         self.__dict__.update(options)
+        self.refresh = self.reload
 
     def __repr__(self):
         return '<%s>' % (self.slug)
 
+    def reload(self):
+        return get(self.slug)
+
 
 def all(params=None, **kwargs):
     if not params:
         params = kwargs
 
-    r = skiff.get('/sizes', params)
-    return [SkiffSize(a) for a in r['sizes']]
+    return skiff.get('/sizes', (lambda r: [SkiffSize(a) for a in r['sizes']]), params)
 
 
 def get(s):
